@@ -1,9 +1,10 @@
-use crate::event::KeyCode;
+use std::{collections::HashSet, error::Error, hash::Hash};
+
 use anyhow::{anyhow, Result};
+use log::{error, info, warn};
 use serde::{Deserialize, Serialize};
-use std::collections::HashSet;
-use std::error::Error;
-use std::hash::Hash;
+
+use crate::event::KeyCode;
 
 #[derive(Serialize, Deserialize, Debug)]
 pub struct KeyConfig {
@@ -198,13 +199,17 @@ impl KeyConfig {
     for line in data.split('\n') {
       if line.starts_with(config) {
         let line = line.trim_start_matches(config).trim_start().trim_end().to_string();
-        if line.len() == 1 {
+        if has_just_one_char(&line) {
           return Some(KeyCode::Char(line.chars().next().unwrap()));
+        } else {
+          error!("Found multiple characters in {} for {}", line, config);
         }
       } else if line.starts_with(&config.replace('-', "_")) {
         let line = line.trim_start_matches(&config.replace('-', "_")).trim_start().trim_end().to_string();
-        if line.len() == 1 {
+        if has_just_one_char(&line) {
           return Some(KeyCode::Char(line.chars().next().unwrap()));
+        } else {
+          error!("Found multiple characters in {} for {}", line, config);
         }
       }
     }
@@ -212,6 +217,11 @@ impl KeyConfig {
   }
 }
 
+fn has_just_one_char(s: &str) -> bool {
+  let mut chars = s.chars();
+  chars.next().is_some() && chars.next().is_none()
+}
+
 #[cfg(test)]
 mod tests {
   use super::*;
