@@ -1,4 +1,4 @@
-use tui::{
+use ratatui::{
   backend::Backend,
   layout::{Alignment, Constraint, Direction, Layout, Rect},
   style::{Color, Modifier, Style},
